openpower: pdata devtree file based attribute override support

attributes tool enabled to track the updates to attributes done
using "write" command. This features requires environment
variable PDATA_ATTR_OVERRIDE is defined and is pointing to a
file path that can be appended to.

This commits add support for setting shell context environment
variable to enable attribute override for devtree attributes.

Refer gerrit review for details

 https://gerrit.openbmc-project.xyz/c/openbmc/openpower-proc-control/
     +/49298

Signed-off-by: Jayanth Othayoth <ojayanth@in.ibm.com>
Change-Id: I744b86018440b6626307d447934152c978f6bd4b
diff --git a/meta-openpower/recipes-bsp/pdata/files/power-target.sh b/meta-openpower/recipes-bsp/pdata/files/power-target.sh
index 10c9850..4a02419 100755
--- a/meta-openpower/recipes-bsp/pdata/files/power-target.sh
+++ b/meta-openpower/recipes-bsp/pdata/files/power-target.sh
@@ -1,6 +1,7 @@
 # Command line debug tools like pdbg and ecmd requires
 # PDBG_DTB environment variable.
 # attributes tool required both PDBG_DTB and PDATA_INFODB.
 
 export PDBG_DTB=/var/lib/phosphor-software-manager/pnor/rw/DEVTREE
 export PDATA_INFODB=/usr/share/pdata/attributes_info.db
+export PDATA_ATTR_OVERRIDE=/tmp/devtree_attr_override
@@ -1,6 +1,7 @@
 # Command line debug tools like pdbg and ecmd requires
 # PDBG_DTB environment variable.
-# attributes tool required both PDBG_DTB and PDATA_INFODB.
+# attributes tool required PDBG_DTB, PDATA_INFODB and PDATA_ATTR_OVERRIDE
 
 export PDBG_DTB=/var/lib/phosphor-software-manager/pnor/rw/DEVTREE